.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xtensor
=======

Defined in ``xtensor/xtensor.hpp``

.. doxygenclass:: xt::xtensor_container
   :project: xtensor
   :members:

.. doxygentypedef:: xt::xtensor
   :project: xtensor

.. doxygentypedef:: xt::xtensor_optional
   :project: xtensor

.. doxygenfunction:: xt::from_indices
   :project: xtensor

.. doxygenfunction:: xt::flatten_indices
   :project: xtensor

.. doxygenfunction:: xt::ravel_indices
   :project: xtensor
